/* -*- mode: c++; c-basic-offset: 3; -*- */
#include "html/document.hh"
#include "html/color.hh"
#include "html/genAttr.hh"
#include "html/tag_only.hh"
#include "html/text.hh"
#include "html/writer.hh"

using namespace html;

//====================================== Construct an empty document
document::document(void) 
   : mHead("head")
{
   init_header();
}

document::document(const char* title) 
   : mHead("head")
{
   setTitle(title);
   init_header();
}

document::~document(void) {
}

document*
document::clone(void) const {
   return new document(*this);
}

void
document::init_header(void) {
   tag_only ctype("meta");
   ctype.attributes().addAttr("Content-Type",
			      genAttr("text/html; charset=iso-8859-1"));
   mHead << ctype;
}

void 
document::write(writer& out) const {
   out.tag("HTML");

   //----------------------------------  Add header section and meta-data
   mHead.write(out);
   out.endLine();

   //----------------------------------  Add style dictionary
   if (!mStyle.empty()) {
      mStyle.write(out);
      out.endLine();
   }

   //----------------------------------  Add body
   compound::write(out);
   out.endTag("HTML");
}

//======================================  Get the tag
const char *
document::getTag(void) const {
   return "BODY";
}

//======================================  Set the background color.
void 
document::setBackgroundColor(const color& clr) {
   compound::repAttr("BGCOLOR", clr);
}

//======================================  Set the refresh period
void 
document::setRefresh(double t) {
   if (t != 0) {
      tag_only ctype("meta");
      ctype.attributes().addAttr("Refresh", genAttr(std::to_string(t)));
      mHead << ctype;
   }
}

//======================================  Set the refresh period
void 
document::setStyle(const std::string& name, const StyleClass& c) {
   mStyle.addClass(name, c);
}

//======================================  Set the dcument title
void 
document::setTitle(const std::string& title) {
   block title_block("title");
   mHead << (title_block << text(title));
}
